package edu.jhu.cs.oose.fall2010.group1.surveyApp.model;

/**
 * Links an object with the value 'true' or 'false.'
 * The object represents the 'appearance' of the choice, while a boolean represents the underlying value.
 * For example, we could assign the <code>String</code> objects 'Yes' and 'No' for true and false respectively,
 * or 'Yes, please' and 'No way.'
 * 
 * @author liu
 *
 * @param <T> The type of object representing this choice.
 */
public class BinaryChoice<T> {
	private boolean value;
	private T obj;
	
	/**
	 * Sole constructor
	 */
	public BinaryChoice(boolean value, T obj) {
		this.value = value;
		this.obj = obj;
	}
	
	/**
	 * Get the boolean value of this choice.
	 * 
	 * @return the boolean value of this choice.
	 */
	public boolean getValue(){
		return value;
	}
	
	/**
	 * Get the object representing this choice.
	 * @return the object representing this choice.
	 */
	public T getObject() {
		return obj;
	}
	
	/**
	 * 
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((obj == null) ? 0 : obj.hashCode());
		result = prime * result + (value ? 1231 : 1237);
		return result;
	}
	
	/**
	 * Only true if both the boolean value and representing object are equal.
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		BinaryChoice<?> other = (BinaryChoice<?>) obj;
		if (this.obj == null) {
			if (other.obj != null)
				return false;
		} else if (!this.obj.equals(other.obj))
			return false;
		if (value != other.value)
			return false;
		return true;
	}
}
