package edu.jhu.cs.oose.fall2010.group1.surveyApp.model;

import java.util.ArrayList;
import java.util.List;
 
/**
  * An abstract class representing all questions that allows selection between choices.
  * 
  * @author liu
  *
  * @param <T> type of object to represent the choices.
  */
public abstract class ChoiceQuestion<T> extends Question {

	private List<T> choices;
	
	/**
	 * Sole constructor.
	 * 
	 * @param newPrompt prompt of the question
	 * @param answerClass class object for the class of object to represent the response to this question 
	 * @param choices <code>Collection</code> of choices to allow selection between.
	 * @throws InvalidChoiceListException if choice list is null
	 */
	public ChoiceQuestion(String newPrompt, Class<?> answerClass, List<T> choices) throws InvalidChoiceListException {
		super(newPrompt, answerClass);
		if (choices == null)
			throw new InvalidChoiceListException();
		this.choices = new ArrayList<T>(choices);
	}
	
	/**
	 * Get the choices accepted by this question
	 * 
	 * @return <code>list</code> of choices accepted by this 
	 */
	public List<T> getChoices() {
		return new ArrayList<T>(choices);
	}
	
	/**
	 * Get the number of choices accepted by this question.
	 * 
	 * @return the number of choices available to this question.
	 */
	public int getNumberOfChoices() {
		return choices.size();
	}
}
