package edu.jhu.cs.oose.fall2010.group1.surveyApp.model;

/**
 * Represents a choice that can be compared against other choices.
 * For example: 'poor', 'fair', 'good', 'excellent'
 * 
 * @author liu
 *
 * @param <T> type of object used to represent this choice.
 */
public class OrdinalChoice<T> {

	private int order;
	private T obj;
	
	/**
	 * Sole Constructor
	 * 
	 * @param order the order of this choices; how it compares to other choices
	 * @param obj object representing this choice
	 */
	public OrdinalChoice(int order, T obj) {
		this.order = order;
		this.obj = obj;
	}
	
	/**
	 * get the integer representing how this choice compares to other choices
	 */
	public int getOrder() {
		return order;
	}
	
	/**
	 * get the object representing this choice.
	 */
	public T getObject() {
		return obj;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((obj == null) ? 0 : obj.hashCode());
		result = prime * result + order;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		OrdinalChoice<?> other = (OrdinalChoice<?>) obj;
		if (this.obj == null) {
			if (other.obj != null)
				return false;
		} else if (!this.obj.equals(other.obj))
			return false;
		if (order != other.order)
			return false;
		return true;
	}
}
