package edu.jhu.cs.oose.fall2010.group1.surveyApp.model;

import java.util.List;

/**
 * Immutable question object containing a prompt and validator/aggregator.
 * Questions specify the type of response they accept.
 * 
 * @author liu
 *
 */
public abstract class Question {
    private String prompt;
    private Class<?> answerClass;
    
    /**
     * default constructor
     * 
     * @param newPrompt prompt for the question
     * @param answerClass class that represents the response to this question
     */
    public Question(String newPrompt, Class<?> answerClass) {
        prompt = newPrompt;
        this.answerClass = answerClass;
    }
    
    /**
     * Gets the prompt
     * @return the prompt for this question
     */
    public String getPrompt() {
        return prompt;
    }
    
    /**
     * @return The class of objects that represents a response to this question
     */
    public Class<?> getAnswerClass() {
    	return answerClass;
    }

    /**
     * Determines if an answer is valid for this question
     * 
     * @param answer the answer to be validated
     * @return true if answer is valid, false otherwise
     */
    public boolean validate(Object answer) {
    	return answer != null && answerClass.isAssignableFrom(answer.getClass());
    }
    
    /**
     * Aggregates a list of answers to return meaningful statistics
     * @param listOfAnswers
     * @return set of statistics
     */
    public abstract List<Statistic> aggregate(List<Object> listOfAnswers);
}
