package edu.jhu.cs.oose.fall2010.group1.surveyApp.model;

import java.util.ArrayList;
import java.util.List;



/**
 * Contains a list of questions. Provides methods for adding, removing, and viewing questions
 * 
 * @author sliu40
 *
 */
public class Survey {
    private List<Question> questions;
    
    /**
     * Constructor; creates a new survey
     */
    public Survey() {
    	questions = new ArrayList<Question>();
    }
    
    /**
     * Adds a question to the end of the survey
     * 
     * @param newQuestion the question to be added
     * @throws QuestionInsertionException if newQuestion == null
     */
    public void addQuestion(Question newQuestion) throws QuestionInsertionException {
    	if (newQuestion == null)
    		throw new QuestionInsertionException();
    	
    	questions.add(newQuestion);
    }
    
    /**
     * Adds a question to the specified index
     * 
     * @param newQuestion the question to be added
     * @param index position to add the question to
     * @throws QuestionInsertionException if newQuestion == null or index > current number of questions
     */
    public void insertQuestion(Question newQuestion, int index) throws QuestionInsertionException {
        if (newQuestion == null)
        	throw new QuestionInsertionException();
    	
    	try {
        	questions.add(index, newQuestion);
        } catch (IndexOutOfBoundsException e) {
        	throw new QuestionInsertionException();
        }
    }
    
    /**
     * Removes a question at the specified index
     * 
     * @param index index of the question to be removed
     * @return the question that was removed
     * @throws NoSuchQustionException if index >= current number of questions
     */
    public Question removeQuestion(int index) throws NoSuchQuestionException {
    	 try {
    	    return questions.remove(index);
         } catch (IndexOutOfBoundsException e) {
         	throw new NoSuchQuestionException();
         }
    }
    
    /**
     * Gets a copy of the list of questions in this survey. Modifying this list does not affect the survey
     * 
     * @return list of questions contained in this survey
     */
    public List<Question> getQuestionList() {
        return new ArrayList<Question>(questions);
    }
    
    /**
     * return the question at the specified index
     * @param index index of the question to get
     * @return the question
     * @throws NoSuchQustionException if index >= current number of questions
     */
    public Question getQuestionAt(int index) throws NoSuchQuestionException{
    	try {
    		return questions.get(index);
    	} catch (IndexOutOfBoundsException e) {
    		throw new NoSuchQuestionException();
    	}
    }
    
    /**
     * 
     * @return current number of questions
     */
    public int getNumberOfQuestions() {
    	return questions.size();
    }

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((questions == null) ? 0 : questions.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Survey other = (Survey) obj;
		if (questions == null) {
			if (other.questions != null)
				return false;
		} else if (!questions.equals(other.questions))
			return false;
		return true;
	}
}
