package edu.jhu.cs.oose.fall2010.group1.surveyApp.model.tests;


import static org.junit.Assert.*;
import java.util.*;
import org.junit.*;
import edu.jhu.cs.oose.fall2010.group1.surveyApp.model.*;

public class SurveyTest {

	private Survey testSurvey = new Survey();
	private MultiChoiceQuestion<String> mtcQuestion1;
	private MultiChoiceQuestion<String> mtcQuestion2;
	private BinaryChoiceQuestion<String> bcQuestion1;
	private BinaryChoiceQuestion<Integer> bcQuestion2;
	private ShortAnswerQuestion saQuestion1;
	private ShortAnswerQuestion saQuestion2;
	
	
	@Before
	public void setUp() throws Exception {
		testSurvey = new Survey();
		mtcQuestion1 = new MultiChoiceQuestion<String>("Multiple Choice Question 1", new ArrayList<String>());
		mtcQuestion2 = new MultiChoiceQuestion<String>("Multiple Choice Question 2", new ArrayList<String>());
		bcQuestion1 = BinaryChoiceQuestion.makeBinaryChoiceQuestion("Binary Choice Question 1", "Option 1", "Option 2");
		bcQuestion2 = BinaryChoiceQuestion.makeBinaryChoiceQuestion("Binary Choice Question 2", 10,15);
		saQuestion1 = new ShortAnswerQuestion("Short Answer Question 1");
		saQuestion2 = new ShortAnswerQuestion("Short Answer Question 2");
		testSurvey.addQuestion(mtcQuestion1);
		testSurvey.addQuestion(bcQuestion1);
		testSurvey.addQuestion(saQuestion1);
		testSurvey.addQuestion(mtcQuestion2);
		
	}
	
	@After
	public void tearDown() {
		testSurvey = null;
		mtcQuestion1 = null;
		mtcQuestion2 = null;
		bcQuestion1 = null;
		bcQuestion2 = null;
		saQuestion1 = null;
		saQuestion2 = null;
	}

	@Test
	public void testAddInsertRemoveQuestion() {
		

		testSurvey.addQuestion(saQuestion2);	
		
		assertEquals(mtcQuestion1, testSurvey.getQuestionAt(0));
		assertEquals(saQuestion1, testSurvey.getQuestionAt(2));
		assertEquals(saQuestion2, testSurvey.getQuestionAt(4));
		
		assertEquals(5, testSurvey.getNumberOfQuestions());
		
		testSurvey.insertQuestion(bcQuestion2, 3);
		
		assertEquals(bcQuestion2, testSurvey.getQuestionAt(3));
		assertEquals(6, testSurvey.getNumberOfQuestions());
		
		testSurvey.removeQuestion(0);
		assertEquals(bcQuestion1, testSurvey.getQuestionAt(0));
		assertEquals(5, testSurvey.getNumberOfQuestions());
		
	}
	
	@Test(expected=QuestionInsertionException.class)
	public void testAddAndInsertNullQuestion() {
		testSurvey.addQuestion(null);
	}
	
	@Test(expected=QuestionInsertionException.class) 
	public void testInsertQuestionOutOfBounds() {
		testSurvey.insertQuestion(bcQuestion2, 10);
	}
	
	@Test(expected=NoSuchQuestionException.class)
	public void testRemoveQuestionOutOfBounds() {
		testSurvey.removeQuestion(10);		
	}
	
	@Test
	public void testEquals() {
		Survey testSurvey2 = new Survey();
		testSurvey2.addQuestion(mtcQuestion1);
		testSurvey2.addQuestion(bcQuestion1);
		testSurvey2.addQuestion(saQuestion1);
		testSurvey2.addQuestion(mtcQuestion2);
		assertTrue(testSurvey.equals(testSurvey2));
		testSurvey2.addQuestion(saQuestion2);
		assertFalse(testSurvey.equals(testSurvey2));
	}

}
